Hacking Quizdrill

The current version of this file is availible at our wiki-page.

# Quizdrill/Hacking

OpenFacts, the Open Source Knowledge Database

< Quizdrill

Patches can be posted on the Patches section of the Issuetracker - or if you prefer - on the devel-mailinglist. Please include a nice log message following the guidelines from Subversion. The wrote it way nicer then we could ever and there is no reason for ever project to do it differently so we just use theirs.